"""
Version information for DLens
"""

__version__ = "1.0.0"
__version_info__ = tuple(int(i) for i in __version__.split('.') if i.isdigit())
__author__ = "Muhammad-NSQ"
__email__ = "muhammednidal122@gmail.com"
__license__ = "MIT"
__description__ = "Enhanced directory mapping and visualization tool"